@@ -1,7 +1,7 @@
 from typing import TypeVar, Generic
 import json
 
-T = TypeVar("T", json, int, str, float, list, dict, tuple)
+T = TypeVar("T")
 
 
 class Parameter(Generic[T]):
@@ -91,7 +91,7 @@ class ListParameter(Parameter[list]):
     pass
 
 
-class DictParameter(Parameter[dict]):
+class JsonParameter(Parameter[dict]):
 
     pass
 
@@ -101,8 +101,4 @@ class TupleParameter(Parameter[tuple]):
     pass
 
 
-class JsonParameter(Parameter[json]):
-
-    pass
-
 
